.. _code_example-name:

!!!!!!!!!!!!
code_example
!!!!!!!!!!!!

.. meta::
   :keywords: code_example,code,command,example,factorial,git,hash,xrst_code,xrst_spell_off,,xrst_spell_on,this,file

.. index:: code_example, code

.. _code_example-title:

Code Command Example
####################

.. contents::
   :local:

.. index:: factorial

.. _code_example@Factorial:

Factorial
*********

.. literalinclude:: ../../example/code.py
   :lines: 14-17
   :language: py

.. index:: git, hash

.. _code_example@Git Hash:

Git Hash
********

.. literalinclude:: ../../example/code.py
   :lines: 24-24
   :language: py

.. index:: xrst_code

.. _code_example@xrst_code:

xrst_code
*********
The file below demonstrates the use of ``xrst_code`` .

.. index:: xrst_spell_off,, xrst_spell_on

.. _code_example@xrst_spell_off, xrst_spell_on:

xrst_spell_off, xrst_spell_on
*****************************
The file below demonstrates the use of ``xrst_spell_off``
and ``xrst_spell_on`` .

.. _code_example@This Example File:

This Example File
*****************

.. literalinclude:: ../../example/code.py
   :language: py
